from setuptools import setup

setup(name='epidistributions',
      version='0.1',
      description='Gaussian distributions',
      author='David Tan',
      packages=['distributions'],
      zip_safe=False)
